from flask import current_app
from itsdangerous import URLSafeTimedSerializer as Serializer
from iot.app import db, login_manager
from flask_login import UserMixin
from datetime import datetime
from iot.blueprints.main.models import Notes
from iot.blueprints.sensor.models import nbiotDevice


# The Default User Loading proccess
@login_manager.user_loader
def load_user(user_id):
    return Users.query.get(int(user_id))


class Users(db.Model, UserMixin):
    __tablename__ = 'users'
    id = db.Column(db.Integer, primary_key=True)
    username = db.Column(db.String(20), unique=True, nullable=False)
    email_account = db.Column(db.String(120), unique=True, nullable=False)
    email_comm = db.Column(db.String(120), unique=False, nullable=False)
    role = db.Column(db.String(120), unique=False, nullable=False, default='user')
    image_file = db.Column(db.String(20), nullable=False, default='def_avatar.png')
    password = db.Column(db.String(60), nullable=False)
    upload_date = db.Column(db.DateTime, nullable=False, default=datetime.utcnow)
    last_update_date = db.Column(db.DateTime, nullable=False, default=datetime.utcnow, onupdate=datetime.utcnow)

    # Relations One To Many
    
    notes = db.relationship('Notes', backref='author', lazy='dynamic')
    devices = db.relationship('nbiotDevice', backref='owner', lazy='dynamic')

   # Here is a one to one relationship: each user can only have one role, and there can be multiple users with the same role
    # type(user.role) = <class 'iot.blueprints.user.models.User_Roles'>
    # type(user.role_id) =  <class 'int'> #
    role_id = db.Column(db.Integer, db.ForeignKey('user_roles.id'), nullable=False, default=2)
    role = db.relationship('User_Roles', backref=db.backref('users', lazy='dynamic'))

    
    def get_reset_token(self, expires_sec=1800):
        s = Serializer(current_app.config['SECRET_KEY'])
        return s.dumps({'user_id': self.id})

    @staticmethod
    def verify_reset_token(token):
        s = Serializer(current_app.config['SECRET_KEY'])
        try:
            user_id = s.loads(token)['user_id']
        except:
            return 0
        return Users.query.get(user_id)


class User_Roles(db.Model):
    __tablename__ = 'user_roles'
    id = db.Column(db.Integer, primary_key=True)
    name = db.Column(db.String(20), unique=True, nullable=False)
    description = db.Column(db.String(200), unique=False, nullable=True)

